@@ -42,8 +42,10 @@ def make_html_images_inline(in_filepath, out_filepath):
         img_path = os.path.join(basepath, img.attrs['src'])
         mimetype = guess_type(img_path)
         try:
-            img.attrs['src'] = \
-                "data:%s;base64,%s" % (mimetype, file_to_base64(img_path))
+            img.attrs['src'] = "data:%s;base64,%s" % (mimetype, file_to_base64(img_path))
+        except:
+            print('ignoring link external img')         
+        
 
     with open(out_filepath, 'w') as of:
         of.write(str(soup))
